OC.L10N.register(
    "contacts",
    {
    "Details" : "Detallar",
    "Contacts" : "Əlaqələr",
    "Rename" : "Adı dəyiş",
    "Send email" : "Email yolla",
    "Delete" : "Sil",
    "Copy link" : "linki nüsxələ",
    "Download" : "Yüklə",
    "can edit" : "dəyişmək olar",
    "Add" : "Əlavə etmək",
    "Save" : "Saxla",
    "Cancel" : "Dayandır",
    "Invalid image" : "Yalnış şəkil",
    "Name" : "Ad",
    "Title" : "Başlıq",
    "Pending" : "Gözləmə",
    "None" : "Heç bir",
    "Close" : "Bağla",
    "Import" : "Əlavə et",
    "Not grouped" : "Qruplaşdırılmayıb",
    "User" : "User",
    "Group" : "Qrup",
    "Email" : "Email",
    "Admin" : "İnzibatçı",
    "Owner" : "Owner",
    "Prefix" : "Prefiks",
    "Suffix" : "Suffiks",
    "Nickname" : "Ləqəb",
    "Notes" : "Qeydlər",
    "Website" : "Veb sayt",
    "Location" : "Yerləşdiyiniz ünvan",
    "Home" : "Ev",
    "Work" : "İş",
    "Other" : "Digər",
    "Address" : "Ünvan",
    "City" : "Şəhər",
    "Country" : "Ölkə",
    "Birthday" : "Ad günü",
    "Anniversary" : "Yubiley",
    "Phone" : "Telefon",
    "Mobile" : "Mobil",
    "Fax" : "Faks",
    "Pager" : "Peycer"
},
"nplurals=2; plural=(n != 1);");
